# 2023-05-29 - Avalanche Root Gauge Factory

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This version has been replaced for an updated version: [AvalancheRootGaugeFactory V2](../../20230811-avalanche-root-gauge-factory-v2/). The new version uses a different bridge for the BAL token, which is considered the canonical one.

Deployment of the `AvalancheRootGaugeFactory`, for stakeless gauges that bridge funds to their Avalanche counterparts.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`AvalancheRootGaugeFactory` artifact](./artifact/AvalancheRootGaugeFactory.json)
